@@ -1,12 +1,22 @@
 
 test_that("marker() catches invalid genotype assignments", {
   x = nuclearPed(1)
-  expect_error(marker(x, 1:3), "Genotype must be a vector of length 1 or 2")
-  expect_error(marker(x, 1,2,3,4), "Too many genotype assignments")
-  expect_error(marker(x, 3:4, alleles = 1:2), "Invalid allele")
+  expect_error(marker(x, 1), "Genotypes must be named")
+  expect_error(marker(x, "4" = 1), "Unknown ID label")
+  expect_error(marker(x, "1" = ""), "Unclear genotype")
+  expect_error(marker(x, "1" = "1/2/3"), "Unclear genotype")
+  expect_error(marker(x, "1" = 1:3), "Unclear genotype")
+  expect_error(marker(x, "1" = 1, "1" = 2), "Multiple genotypes given for individual")
+  expect_error(marker(x, "1" = "3/4", alleles = 1:2), "Invalid allele")
+  expect_error(marker(x, "1" = 1, allelematrix = 0), "When specifying genotypes, `allelematrix` must be NULL")
 
-  expect_error(marker(x, geno = 1:2), "`geno` incompatible with pedigree")
-  expect_error(marker(x, geno = 1:3, allelematrix = 0), "At least one of `geno` and `allelematrix` must be NULL")
+  expect_error(marker(x, geno = 1), "Genotypes must be named")
+  expect_error(marker(x, geno = c("4" = 1)), "Unknown ID label")
+  expect_error(marker(x, geno = c("1" = "")), "Unclear genotype")
+  expect_error(marker(x, geno = c("1" = "1/2/3")), "Unclear genotype")
+  expect_error(marker(x, geno = c("1" = 1, "1" = 2)), "Multiple genotypes given for individual")
+  expect_error(marker(x, geno = c("1" = "3/4"), alleles = 1:2), "Invalid allele")
+  expect_error(marker(x, geno = c("1" = 1), allelematrix = 0), "When specifying genotypes, `allelematrix` must be NULL")
 })
 
 test_that("marker() assigns genotypes with `geno`", {
@@ -16,7 +26,7 @@ test_that("marker() assigns genotypes with `geno`", {
 
   x = nuclearPed(1)
   expect_equal(marker(x, geno = c(NA, "a/b", 0)), marker(x, '2' = "a/b"))
-  expect_equal(marker(x, geno = 1:3), marker(x, '1'=1, '2'=2, '3'=3))
+  expect_equal(marker(x, geno = c('3'=3, '2'=2, '1'=1)), marker(x, '1'=1, '2'=2, '3'=3))
 })
 
 test_that("empty markers are created correctly", {
@@ -43,7 +53,7 @@ test_that("alleles and freqs are sorted together", {
 
 })
 
-test_that("marker() catces various errors", {
+test_that("marker() catches various errors", {
   x = nuclearPed(1)
   expect_error(marker(x, alleles = c(1,1)),
                "Duplicated allele label: 1")
