@@ -13,6 +13,15 @@ test_that("isXmarker() works", {
   expect_false(isXmarker(marker(x, chrom=1)))
 })
 
+test_that("nMarkers() and hasMarkers() works with multiple comps", {
+  x = list(singleton(1), singleton(2) |> addMarker())
+  expect_error(nMarkers(x), "pedigree components have different number of markers")
+  expect_identical(nMarkers(x, compwise = T), 0:1)
+
+  expect_true(hasMarkers(x), "pedigree components have different number of markers")
+  expect_identical(hasMarkers(x, compwise = T), c(F,T))
+})
+
 test_that("setMarkers() attaches a list of markers", {
   m = marker(x)
   x1 = setMarkers(x, m)
